#!/usr/local/bin/perl -w

=head1 NAME

vcp.t - testing of vcp command

=cut

use strict ;

use Carp ;
use Test ;
use IPC::Run ;
use VCP::TestUtils qw( vcp_cmd );

my @vcp = vcp_cmd ;

# Note the spaces instead of tabs and the spaces after the null:
my $null_transfer = <<'END_TRANSFER';
Source:
        null:   

Destination:    null:  
END_TRANSFER

# Note the spaces instead of tabs and the spaces after the null:
my $identity_transfer = <<'END_TRANSFER';
Source:
        null:   

Destination:    null:  

Identity:
END_TRANSFER

# run vcp command line with given parameters
sub vcp {
   my $exp_results = shift ;
   my $out ;
   my $err ;
   my $pid = IPC::Run::run [ @vcp, @_ ], \undef, \$out, \$err ;
   confess "vcp ", join( ' ', @_ ), " returned $?\n$out$err"
      if defined $exp_results && ! grep $? == $_ << 8, @$exp_results ;
   return $err . $out ;
}


sub test_helper {
   my ( $cli_params, $stdin ) = @_;
   my $ok = eval {
       VCP::TestUtils::run [ @vcp, @$cli_params ], $stdin ? ( "<", \$stdin ) : ();
       1;
   };
   @_ = (
      $ok || $@,
      1,
      join " ",
         "vcp",
         @$cli_params,
         $stdin
            ? ( "<", qq{\\"$stdin"} )
            : ()
   );
   goto &ok;
}


my @tests = (
#perldoc now complains when run as root, causing this test to fail
#sub { ok vcp( [ 0  ], 'help' ),            qr/OPTIONS/s                       },
sub { test_helper [ qw( null: null:                     ) ] },
sub { test_helper [ qw( null: identity: null:           ) ] },
sub { test_helper [ qw( null: identity: identity: null: ) ] },
sub { test_helper [ "vcp:-"                               ], $null_transfer },
sub { test_helper [ "vcp:-"                               ], $identity_transfer },

sub { ok vcp( [ 2  ], 'foo:' ),             qr/unknown source scheme/s        },
sub { ok vcp( [ 2  ], 'revml:', 'foo:' ),   qr/unknown dest\w* scheme/s       },
sub { ok vcp( [ 1  ], '--foo' ),            qr/foo.*Usage/s                   },
) ;

plan tests => scalar( @tests ) ;

$_->() for @tests ;
